#
# spec file for package python-Flask
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Flask
Version:        0.10.1
Release:        7.2
Url:            http://github.com/mitsuhiko/flask/
Summary:        A microframework based on Werkzeug, Jinja2 and good intentions
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/F/Flask/Flask-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-Sphinx
BuildRequires:  python-Werkzeug >= 0.7
BuildRequires:  python-devel
BuildRequires:  python-itsdangerous >= 0.21
BuildRequires:  python-nose
BuildRequires:  python-setuptools
Requires:       python-Jinja2 >= 2.4
Requires:       python-Werkzeug >= 0.7
Requires:       python-itsdangerous >= 0.21
Provides:       python-flask = %{version}
Obsoletes:      python-flask < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Flask is a microframework for Python based on Werkzeug, Jinja 2 and good
intentions. And before you ask: It's BSD licensed!

%package doc
Summary:        Documentation for python-Flask
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
This package contains HTML documentation, including tutorials and API
reference for python-Flask.

%prep
%setup -q -n Flask-%{version}
rm docs/.gitignore # Remove junk

%build
python setup.py build
#cd docs && make html

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}%{python_sitelib}

%if 0%{?suse_version} > 1210
%check
python setup.py test
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE
%{python_sitelib}/*

%files doc
%defattr(-,root,root)
%doc docs examples

%changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Sep  9 2013 dmueller@suse.com
- add dependency on itsdangerous
* Tue Jun 25 2013 dmueller@suse.com
- update to 0.10.1
  - Fixed an issue where ``|tojson`` was not quoting single quotes which
  made the filter not work properly in HTML attributes.  Now it's
  possible to use that filter in single quoted attributes.  This should
  make using that filter with angular.js easier.
  - Added support for byte strings back to the session system.  This broke
  compatibility with the common case of people putting binary data for
  token verification into the session.
  - Fixed an issue were registering the same method twice for the same endpoint
  would trigger an exception incorrectly.
  :ref:`upgrading-to-010` for more information.
  - Added ``template_test`` methods in addition to the already existing
  ``template_filter`` method family.
  - Added ``template_global`` methods in addition to the already existing
  ``template_filter`` method family.
  - Set the content-length header for x-sendfile.
  - ``tojson`` filter now does not escape script blocks in HTML5 parsers.
  - ``tojson`` used in templates is now safe by default due.  This was
  allowed due to the different escaping behavior.
  - Flask will now raise an error if you attempt to register a new function
  on an already used endpoint.
  - Added wrapper module around simplejson and added default serialization
  of datetime objects.  This allows much easier customization of how
  JSON is handled by Flask or any Flask extension.
  - Removed deprecated internal ``flask.session`` module alias.  Use
  ``flask.sessions`` instead to get the session module.  This is not to
  be confused with ``flask.session`` the session proxy.
  - Templates can now be rendered without request context.  The behavior is
  slightly different as the ``request``, ``session`` and ``g`` objects
  will not be available and blueprint's context processors are not
  called.
  - The config object is now available to the template as a real global and
  not through a context processor which makes it available even in imported
  templates by default.
  - Added an option to generate non-ascii encoded JSON which should result
  in less bytes being transmitted over the network.  It's disabled by
  default to not cause confusion with existing libraries that might expect
  ``flask.json.dumps`` to return bytestrings by default.
  - ``flask.g`` is now stored on the app context instead of the request
  context.
  - ``flask.g`` now gained a ``get()`` method for not erroring out on non
  existing items.
  - ``flask.g`` now can be used with the ``in`` operator to see what's defined
  and it now is iterable and will yield all attributes stored.
  - ``flask.Flask.request_globals_class`` got renamed to
  ``flask.Flask.app_ctx_globals_class`` which is a better name to what it
  does since 0.10.
  - `request`, `session` and `g` are now also added as proxies to the template
  context which makes them available in imported templates.  One has to be
  very careful with those though because usage outside of macros might
  cause caching.
  - Flask will no longer invoke the wrong error handlers if a proxy
  exception is passed through.
  - Added a workaround for chrome's cookies in localhost not working
  as intended with domain names.
  - Changed logic for picking defaults for cookie values from sessions
  to work better with Google Chrome.
  - Added `message_flashed` signal that simplifies flashing testing.
  - Added support for copying of request contexts for better working with
  greenlets.
  - Removed custom JSON HTTP exception subclasses.  If you were relying on them
  you can reintroduce them again yourself trivially.  Using them however is
  strongly discouraged as the interface was flawed.
  - Python requirements changed: requiring Python 2.6 or 2.7 now to prepare
  for Python 3.3 port.
  - Changed how the teardown system is informed about exceptions.  This is now
  more reliable in case something handles an exception halfway through
  the error handling process.
  - Request context preservation in debug mode now keeps the exception
  information around which means that teardown handlers are able to
  distinguish error from success cases.
  - Added the ``JSONIFY_PRETTYPRINT_REGULAR`` configuration variable.
  - Flask now orders JSON keys by default to not trash HTTP caches due to
  different hash seeds between different workers.
  - Added `appcontext_pushed` and `appcontext_popped` signals.
  - The builtin run method now takes the ``SERVER_NAME`` into account when
  picking the default port to run on.
  - Added `flask.request.get_json()` as a replacement for the old
  `flask.request.json` property.
* Fri Nov 16 2012 saschpe@suse.de
- Disable testsuite on SLE_11_SP2
* Thu Nov 15 2012 saschpe@suse.de
- Update to version 0.9:
  + The :func:flask.Request.on_json_loading_failed now returns a JSON formatted
    response by default.
  + The :func:flask.url_for function now can generate anchors to the
    generated links.
  + The :func:flask.url_for function now can also explicitly generate
    URL rules specific to a given HTTP method.
  + Logger now only returns the debug log setting if it was not set
    explicitly.
  + Unregister a circular dependency between the WSGI environment and
    the request object when shutting down the request.  This means that
    environ werkzeug.request will be None after the response was
    returned to the WSGI server but has the advantage that the garbage
    collector is not needed on CPython to tear down the request unless
    the user created circular dependencies themselves.
  + Session is now stored after callbacks so that if the session payload
    is stored in the session you can still modify it in an after
    request callback.
  + The :class:flask.Flask class will avoid importing the provided import name
    if it can (the required first parameter), to benefit tools which build Flask
    instances programmatically.  The Flask class will fall back to using import
    on systems with custom module hooks, e.g. Google App Engine, or when the
    import name is inside a zip archive (usually a .egg) prior to Python 2.7.
  + Blueprints now have a decorator to add custom template filters application
    wide, :meth:flask.Blueprint.app_template_filter.
  + The Flask and Blueprint classes now have a non-decorator method for adding
    custom template filters application wide,
    :meth:flask.Flask.add_template_filter and
    :meth:flask.Blueprint.add_app_template_filter.
  + The :func:flask.get_flashed_messages function now allows rendering flashed
    message categories in separate blocks, through a category_filter
    argument.
  + The :meth:flask.Flask.run method now accepts None for host and port
    arguments, using default values when None.  This allows for calling run
    using configuration values, e.g. app.run(app.config.get('MYHOST'),
    app.config.get('MYPORT')), with proper behavior whether or not a config
    file is provided.
  + Please look into CHANGES for more...
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 0.8:
  * Refactored session support into a session interface so that
    the implementation of the sessions can be changed without
    having to override the Flask class.
  * Empty session cookies are now deleted properly automatically.
  * View functions can now opt out of getting the automatic
    OPTIONS implementation.
  * HTTP exceptions and Bad Request errors can now be trapped so that they
    show up normally in the traceback.
  * Flask in debug mode is now detecting some common problems and tries to
    warn you about them.
  * Flask in debug mode will now complain with an assertion error if a view
    was attached after the first request was handled.  This gives earlier
    feedback when users forget to import view code ahead of time.
  * Added the ability to register callbacks that are only triggered once at
    the beginning of the first request. (:meth:Flask.before_first_request)
  * Malformed JSON data will now trigger a bad request HTTP exception instead
    of a value error which usually would result in a 500 internal server
    error if not handled.  This is a backwards incompatible change.
  * Applications now not only have a root path where the resources and modules
    are located but also an instane path which is the designated place to
    drop files that are modified at runtime (uploads etc.).  Also this is
    conceptionally only instance depending and outside version control so it's
    the perfect place to put configuration files etc.  For more information
    see :ref:instance-folders.
  * Added the APPLICATION_ROOT configuration variable.
  * Implemented :meth:~flask.testing.TestClient.session_transaction to
    easily modify sessions from the test environment.
  * Refactored test client internally.  The APPLICATION_ROOT configuration
    variable as well as SERVER_NAME are now properly used by the test client
    as defaults.
  * Added :attr:flask.views.View.decorators to support simpler decorating of
    pluggable (class based) views.
  * Fixed an issue where the test client if used with the with statement did not
    trigger the execution of the teardown handlers.
  * Added finer control over the session cookie parameters.
  * HEAD requests to a method view now automatically dispatch to the get
    method if no handler was implemented.
  * Implemented the virtual :mod:flask.ext package to import extensions from.
  * The context preservation on exceptions is now an integral component of
    Flask itself and no longer of the test client.  This cleaned up some
    internal logic and lowers the odds of runaway request contexts in unittests.
* Thu Sep 22 2011 saschpe@suse.de
- Set license to BSD-3-Clause (SPDX style)
- Require python-distribute instead of python-setuptools
- Remove %%clean section
* Wed Jul 20 2011 saschpe@gmx.de
- Initial package, replaces python-flask
